package com.ruoyi.brewery.mapper;

import java.util.List;
import com.ruoyi.brewery.domain.WyBreweryRole;
import com.ruoyi.common.core.domain.entity.SysRole;

/**
 * 角色信息Mapper接口
 * 
 * @author ruoyi
 * @date 2025-03-10
 */
public interface WyBreweryRoleMapper 
{
    /**
     * 查询角色信息
     * 
     * @param roleId 角色信息主键
     * @return 角色信息
     */
    public WyBreweryRole selectWyBreweryRoleByRoleId(Long roleId);

    public List<WyBreweryRole> selectRolesByUserName(String userName);

    /**
     * 查询角色信息列表
     * 
     * @param wyBreweryRole 角色信息
     * @return 角色信息集合
     */
    public List<WyBreweryRole> selectWyBreweryRoleList(WyBreweryRole wyBreweryRole);

    /**
     * 新增角色信息
     * 
     * @param wyBreweryRole 角色信息
     * @return 结果
     */
    public int insertWyBreweryRole(WyBreweryRole wyBreweryRole);

    /**
     * 修改角色信息
     * 
     * @param wyBreweryRole 角色信息
     * @return 结果
     */
    public int updateWyBreweryRole(WyBreweryRole wyBreweryRole);

    /**
     * 删除角色信息
     * 
     * @param roleId 角色信息主键
     * @return 结果
     */
    public int deleteWyBreweryRoleByRoleId(Long roleId);

    /**
     * 批量删除角色信息
     * 
     * @param roleIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteWyBreweryRoleByRoleIds(Long[] roleIds);
}
